# FLPInspect

> A GUI tool to inspect and modify an FLP.

**FLPInspect**, is a GUI tool to inspect the internal event structure which is abstracted by [PyFLP](https://github.com/demberto/PyFLP).
You can read and edit FLP files.

![Event View](docs/img/event_view.png)

## Installation

FLPInspect require Python 3.6+

- Via `pip` [**Recommended**]:
  ```
  pip install --upgrade flpinspect
  ```

- **OR**, via [releases](https://github.com/demberto/FLPInspect/releases)
  - Install required dependencies:
    ```
    pip install -rrequirements.txt
    ```

### Note for Mac users

_Although FLPInspect is cross-platform, Tkinter has some issues with Mac, I don't have a Mac to test myself. **The bugs will only be minor UI bugs at most.**_

## [Documentation](https://demberto.github.io/FLPInspect)

### [Project Goals & Issues](TODO.md)

## License

**FLPInspect** is licensed under the [GNU Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html)
